Contains the Buffer trait and any build in implementations.

Modules

File IO abstractions to help in implementing custom buffers

Escape sequence interpreter to aid in buffer implementation

Structs

VecBuffer, the default Buffer implementation

Traits

Trait that defines a buffer supporting ’ed’s base commands

Functions

Verify that the index is between 0 and buffer.len() inclusive.

Verify that index is between 1 and buffer.len() inclusive

Verify that all lines in the selection exist and that it isn’t empty.