Struct add_ed::Ed

source · []
pub struct Ed<'a, B: Buffer> { /* private fields */ }
The state variable used by the editor to track its internal state

Implementations

Construct a new instance of Ed

  • An empty file string is recommended if no filepath is opened
  • Note that you can initialise the buffer with contents before this, but those contents will be overwritten if a path is given.
  • macros behave like scripts given to the ‘g’ command an example is “a\n\n.\n” which appends an empty line

Run the given command

Returns true if the command was to quit

Run given instance of Ed until it receives a command to quit or errors

The returned error type could be improved, suggestions welcome.

Get an immutable reference to part of the editors state