Struct add_ed::Line

source ·
pub struct Line {
    pub tag: Rc<Cell<char>>,
    pub text: Rc<String>,
    /* private fields */
}
Text data and metadata for a single line of text

Note the Rc<Cell>s placed around internal variables we wish to share between points in history while allowing modification, both in that Rc and without &mut access to the line. This is to let [History] enforce use of [History::current_mut] to edit the text, while allowing changes to other data using [History::current] (which doesn’t create undo snapshots).

Fields

tag: Rc<Cell<char>>

The tag set on the given line

It is stored in an Rc to have a shared overwriteable tag for all historical instances of the line.

text: Rc<String>

The text data for a given line

It is stored in an Rc as a CoW mechanism, since it allows a shared allocation for historical states with the same text data while preventing modification of that shared state. To modify, create a new String with the data you want and put it in a new Rc in this field.