This is a dummy UI. That means it simulates an UI without interfacing with any users.
How to use:
- Put the input to simulate line-by-line in the input variable.
- If you want output from print commands put the UI to print with in print_ui.
Fields
input: VecDeque<String>print_ui: Option<&'a mut dyn UI>Trait Implementations
sourceimpl<'a> UI for DummyUI<'a>
impl<'a> UI for DummyUI<'a>
sourcefn get_command(
&mut self,
_ed: EdState<'_>,
_prefix: Option<char>
) -> Result<String, &'static str>
fn get_command(
&mut self,
_ed: EdState<'_>,
_prefix: Option<char>
) -> Result<String, &'static str>
Get a command for parsing and execution Read more
sourcefn get_input(
&mut self,
_ed: EdState<'_>,
terminator: char
) -> Result<Vec<String>, &'static str>
fn get_input(
&mut self,
_ed: EdState<'_>,
terminator: char
) -> Result<Vec<String>, &'static str>
Get input lines until given character is entered alone on a line Read more