Enum add_ed::io::local_io::LocalIOError
source · pub enum LocalIOError {
FilePermissionDenied {
path: String,
},
FileNotFound {
path: String,
},
FileIOFailed {
path: String,
error: Error,
},
ChildCreationFailed(Error),
ChildFailedToStart(Error),
ChildReturnedError(i32),
ChildKilledBySignal,
ChildPipingError,
BadUtf8(FromUtf8Error),
}Expand description
Error type for [LocalIO]
Variants
FilePermissionDenied
Permission denied when performing current operation on path.
FileNotFound
Path not found. May be failing to read file at path, or the directory to create a file in doesn’t exist.
FileIOFailed
More general failure to perform file operation on path, as std::io::Error doesn’t report all the details in a reasonably accessible way.
ChildCreationFailed(Error)
The child thread running the shell command couldn’t be created.
ChildFailedToStart(Error)
The child thread running the shell command failed to begin execution.
ChildReturnedError(i32)
The child thread running a shell command returned a non-zero integer
ChildKilledBySignal
The child thread running a shell command was killed by a signal
ChildPipingError
Error occured in the child thread handling piping
BadUtf8(FromUtf8Error)
Failed to convert data read from file or command into UTF8